#version 330 core

const float PI = 3.1415926535897932384626433832795;

in vec2 uv;
in float dist;
in vec4 rgbaFog;
in float fogAmount;

out vec4 outColor;

uniform int riftIndex;
uniform sampler2D tex;
uniform sampler2D depthTex;
uniform vec2 invFrameSize;
uniform float counter;
uniform float counterSmooth;

#include noise2d.ash
#include fogandlight.fsh

void main()
{
	float x = gl_FragCoord.x * invFrameSize.x;
	float y = gl_FragCoord.y * invFrameSize.y;
	
	float z1 = linearDepth(texture(depthTex, vec2(x,y)).r); //depth from gbuffer depth, a float32 texture
	float z2 = linearDepth(gl_FragCoord.z);
	
	float aDiff = max(0, z2 - z1) * 1000;
	if (aDiff > 2) discard;

	vec2 pos = vec2(x, y);
	
	float f = length(uv - 0.5) * 2;
	
	float noise = 
		cnoise2(vec2(gl_FragCoord.x / 300, gl_FragCoord.y / 300 - counter / 3))  / 50.0
		+ cnoise2(vec2(gl_FragCoord.x / 200, gl_FragCoord.y / 200 - counter / 4))  / 75.0
		+ cnoise2(vec2(gl_FragCoord.x / 2, gl_FragCoord.y / 2 - counter)) / 200.0
	;
	
	vec4 col = vec4(0, 0.5, 0, 1);
	
	float seed = riftIndex/10.0 + counterSmooth / 10.0;
	float spikeNoise = cnoise2(vec2(riftIndex, f * counterSmooth/100.0)) + cnoise2(vec2(riftIndex + 4, f * counterSmooth/10.0)) / 15.0;
	float angle = mod(atan(uv.y - 0.5, uv.x - 0.5) + spikeNoise, 2*3.14159);
	
	float k = cnoise2(vec2(angle * 20, seed))/4 + cnoise2(vec2(angle * 5, seed))/4 + cnoise2(vec2(seed, angle));
	k = k / 2 + 1;
	k = (k - 0.2) * 1.3;
	
	float b = pow(1.2 - f * k, 1.2);
	
	b *= pow(1 - f, 0.1);
	
	col.a = clamp(b, 0, 1);
	col.a = pow(col.a, 4);
	col.a = clamp(col.a - aDiff, 0, 1);
	
	col.a -= clamp((dist * (1 + fogAmount/2.0) - 50) / 40, 0, 0.7 + fogAmount * 0.3);
	
	outColor.rgb = texture(tex, pos).rgb;
	outColor.a = col.a;
	if (outColor.a < 0.02) discard;	
}